@@ -4,14 +4,14 @@ from libcove.lib.common import SchemaJsonMixin
 class SchemaBODS(SchemaJsonMixin):
 
     def __init__(self, json_data=None, lib_cove_bods_config=None):
-        self.lib_cove_bods_config = lib_cove_bods_config
+        self.config = lib_cove_bods_config
         if isinstance(json_data, list) and len(json_data) > 0:
             self.schema_version, self.pkg_schema_url, self.schema_host = \
                 self.get_schema_version_of_statement(json_data[0])
         else:
-            self.pkg_schema_url = lib_cove_bods_config.config['schema_url']
-            self.schema_host = lib_cove_bods_config.config['schema_url_host']
-            self.schema_version = lib_cove_bods_config.config['schema_version']
+            self.pkg_schema_url = self.config.config['schema_url']
+            self.schema_host = self.config.config['schema_url_host']
+            self.schema_version = self.config.config['schema_version']
 
     def get_entity_statement_types_list(self):
         for statement_schema in self._pkg_schema_obj['items']['oneOf']:
@@ -36,13 +36,13 @@ class SchemaBODS(SchemaJsonMixin):
                 and 'bodsVersion' in statement['publicationDetails'] \
                 and statement['publicationDetails']['bodsVersion']:
             version = statement['publicationDetails']['bodsVersion']
-            if version in self.lib_cove_bods_config.config['schema_versions']:
-                return version, self.lib_cove_bods_config.config['schema_versions'][version]['schema_url'], \
-                       self.lib_cove_bods_config.config['schema_versions'][version]['schema_url_host']
+            if version in self.config.config['schema_versions']:
+                return version, self.config.config['schema_versions'][version]['schema_url'], \
+                       self.config.config['schema_versions'][version]['schema_url_host']
 
         # In which case, default schema
-        return self.lib_cove_bods_config.config['schema_version'], self.lib_cove_bods_config.config['schema_url'], \
-            self.lib_cove_bods_config.config['schema_version']
+        return self.config.config['schema_version'], self.config.config['schema_url'], \
+            self.config.config['schema_version']
 
     def get_address_types_allowed_in_entity_statement(self):
         return ('registered', 'business', 'alternative')
